@@ -1,62 +1,25 @@
 use chrono::{DateTime, Local, NaiveDate, NaiveDateTime, NaiveTime, ParseError, Utc};
 use rust_decimal::Decimal;
-use std::{
-    collections::HashMap, fmt, num::ParseFloatError, num::ParseIntError, str::ParseBoolError,
-};
+use std::{collections::HashMap, num::ParseFloatError, num::ParseIntError, str::ParseBoolError};
 
 use crate::ast::*;
 
-#[derive(Debug)]
-pub struct Error {
-    target: String,
-    error: String,
-}
-impl Error {
-    fn new<E>(target: &str, error: E) -> Self
-    where
-        E: fmt::Display,
-    {
-        Self {
-            target: target.into(),
-            error: error.to_string(),
-        }
-    }
-}
-impl fmt::Display for Error {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "Cannot parse to {}: {}", self.target, self.error)
-    }
-}
-impl std::error::Error for Error {}
-impl From<ParseIntError> for Error {
-    fn from(err: ParseIntError) -> Self {
-        Self::new("int", err)
-    }
-}
-impl From<ParseFloatError> for Error {
-    fn from(err: ParseFloatError) -> Self {
-        Self::new("float", err)
-    }
-}
-impl From<ParseBoolError> for Error {
-    fn from(err: ParseBoolError) -> Self {
-        Self::new("bool", err)
-    }
-}
-impl From<ParseError> for Error {
-    fn from(err: ParseError) -> Self {
-        Self::new("chrono", err)
-    }
-}
-impl From<rust_decimal::Error> for Error {
-    fn from(err: rust_decimal::Error) -> Self {
-        Self::new("decimal", err)
-    }
-}
-impl From<serde_json::Error> for Error {
-    fn from(err: serde_json::Error) -> Self {
-        Self::new("serde_json", err)
-    }
+#[derive(Debug, thiserror::Error)]
+pub enum Error {
+    #[error("Cannot parse to int: {0}")]
+    ParseInt(#[from] ParseIntError),
+    #[error("Cannot parse to float: {0}")]
+    ParseFloat(#[from] ParseFloatError),
+    #[error("Cannot parse to bool: {0}")]
+    ParseBool(#[from] ParseBoolError),
+    #[error("Cannot parse to chrono: {0}")]
+    ParseChrono(#[from] ParseError),
+    #[error("Cannot parse to decimal: {0}")]
+    ParseDecimal(#[from] rust_decimal::Error),
+    #[error("Cannot serialize: {0}")]
+    Serialization(#[from] serde_json::Error),
+    #[error("Cannot find key {0} in types")]
+    UnknownKey(String),
 }
 
 pub type Result<T> = std::result::Result<T, Error>;
@@ -119,7 +82,6 @@ pub fn interpret_expression(
     renames: &MysqlRenames,
     types: &MysqlTypes,
 ) -> Result<(String, Vec<MysqlType>)> {
-    let fallback_type = MysqlType::StringLike(Some("".into()));
     Ok(match &expression.node {
         Expr::And(left, right) => {
             let (left_clause, mut left_types) = interpret_expression(left, renames, types)?;
@@ -140,45 +102,45 @@ pub fn interpret_expression(
             (format!("(NOT {})", clause), types)
         }
         Expr::Equal(key, target) => (
-            format!("`{}` = ?", renames.get(key).unwrap_or_else(|| key)),
+            format!("{} = ?", renames.get(key).unwrap_or_else(|| key)),
             vec![types
                 .get(key)
-                .unwrap_or_else(|| &fallback_type)
+                .ok_or(Error::UnknownKey(key.to_string()))?
                 .replace_and_return(target)?],
         ),
         Expr::EqualCI(key, target) => (
-            format!("`{}` LIKE ?", renames.get(key).unwrap_or_else(|| key)),
+            format!("{} LIKE ?", renames.get(key).unwrap_or_else(|| key)),
             vec![types
                 .get(key)
-                .unwrap_or_else(|| &fallback_type)
+                .ok_or(Error::UnknownKey(key.to_string()))?
                 .replace_and_return(target)?],
         ),
         Expr::Greater(key, target) => (
-            format!("`{}` > ?", renames.get(key).unwrap_or_else(|| key)),
+            format!("{} > ?", renames.get(key).unwrap_or_else(|| key)),
             vec![types
                 .get(key)
-                .unwrap_or_else(|| &fallback_type)
+                .ok_or(Error::UnknownKey(key.to_string()))?
                 .replace_and_return(target)?],
         ),
         Expr::Less(key, target) => (
-            format!("`{}` < ?", renames.get(key).unwrap_or_else(|| key)),
+            format!("{} < ?", renames.get(key).unwrap_or_else(|| key)),
             vec![types
                 .get(key)
-                .unwrap_or_else(|| &fallback_type)
+                .ok_or(Error::UnknownKey(key.to_string()))?
                 .replace_and_return(target)?],
         ),
         Expr::Wildcard(key, target) => (
-            format!("`{}` LIKE ?", renames.get(key).unwrap_or_else(|| key)),
+            format!("{} LIKE ?", renames.get(key).unwrap_or_else(|| key)),
             vec![types
                 .get(key)
-                .unwrap_or_else(|| &fallback_type)
+                .ok_or(Error::UnknownKey(key.to_string()))?
                 .replace_and_return(&target.replace("*", "%").replace("?", "_"))?],
         ),
         Expr::Regex(key, target) => (
-            format!("`{}` = ?", renames.get(key).unwrap_or_else(|| key)),
+            format!("{} = ?", renames.get(key).unwrap_or_else(|| key)),
             vec![types
                 .get(key)
-                .unwrap_or_else(|| &fallback_type)
+                .ok_or(Error::UnknownKey(key.to_string()))?
                 .replace_and_return(target)?],
         ),
         Expr::In(key, targets) => {
@@ -186,7 +148,7 @@ pub fn interpret_expression(
                 "FALSE".to_string()
             } else {
                 format!(
-                    "`{}` IN ({})",
+                    "{} IN ({})",
                     renames.get(key).unwrap_or_else(|| key),
                     targets.iter().map(|_| "?").collect::<Vec<_>>().join(", ")
                 )
@@ -196,16 +158,21 @@ pub fn interpret_expression(
                 binds.push(
                     types
                         .get(key)
-                        .unwrap_or_else(|| &fallback_type)
+                        .ok_or(Error::UnknownKey(key.to_string()))?
                         .replace_and_return(target)?,
                 );
             }
             (sql, binds)
         }
-        Expr::IsNone(key) => (
-            format!("`{}` IS NULL", renames.get(key).unwrap_or_else(|| key)),
-            vec![],
-        ),
+        Expr::IsNone(key) => {
+            if !types.contains_key(key) {
+                return Err(Error::UnknownKey(key.to_string()));
+            }
+            (
+                format!("{} IS NULL", renames.get(key).unwrap_or_else(|| key)),
+                vec![],
+            )
+        }
     })
 }
 
